#region Using declarations
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.ComponentModel.DataAnnotations;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Input;
using System.Windows.Media;
using System.Xml.Serialization;
using NinjaTrader.Cbi;
using NinjaTrader.Gui;
using NinjaTrader.Gui.Chart;
using NinjaTrader.Gui.SuperDom;
using NinjaTrader.Gui.Tools;
using NinjaTrader.Data;
using NinjaTrader.NinjaScript;
using NinjaTrader.Core.FloatingPoint;
using NinjaTrader.NinjaScript.DrawingTools;
using System.Diagnostics;
#endregion

//This namespace holds Indicators in this folder and is required. Do not change it. 
namespace NinjaTrader.NinjaScript.Indicators
{
    public class RenkoMarsi : Indicator
    {
        protected override void OnStateChange()
        {
            if (State == State.SetDefaults)
            {
                Description = @"Renko Marsi";
                Name = "Renko Marsi";

                Calculate = Calculate.OnEachTick;
                IsOverlay = false;
                DisplayInDataBox = true;
                DrawOnPricePanel = false;
                DrawHorizontalGridLines = true;
                DrawVerticalGridLines = true;
                PaintPriceMarkers = true;
                ScaleJustification = NinjaTrader.Gui.Chart.ScaleJustification.Right;
                //Disable this property if your indicator requires custom values that cumulate with each new market data event. 
                //See Help Guide for additional information.
                IsSuspendedWhileInactive = true;
                MaximumBarsLookBack = MaximumBarsLookBack.Infinite;
                //
                RSIOMA = 7;
                RSIOMA_MODE = RENKOMARSI_MA_TYPE.EMA;
                RSIOMA_PRICE = RENKOMARSI_PRICE_SRC.CLOSE;
                Ma_RSIOMA = 7;
                Ma_RSIOMA_MODE = RENKOMARSI_MA_TYPE.EMA;
                BuyTrigger = 20;
                SellTrigger = 80;
                BuyTriggerColor = Brushes.Magenta;
                SellTriggerColor = Brushes.DodgerBlue;
                MainTrendLong = 50;
                MainTrendShort = 50;
                MainTrendLongColor = Brushes.Red;
                MainTrendShortColor = Brushes.Green;
                //
                //alertOn = false;
                MainAlerts = false;
                AuxiliaryAlerts = false;
                alertBarIndex = 1;
                alertMessage = true;
                alertSound = true;
                soundFName = "alert1.wav";
                alertTitle = "Renko Marsi Alert";
                nMax = 5000;
                //
                int hisWid = 6;
                AddPlot(new Stroke(Brushes.Red, DashStyleHelper.Solid, hisWid), PlotStyle.Bar, "BDN");
                AddPlot(new Stroke(Brushes.Green, DashStyleHelper.Solid, hisWid), PlotStyle.Bar, "BUP");
                AddPlot(new Stroke(Brushes.Magenta, DashStyleHelper.Solid, hisWid), PlotStyle.Bar, "SDN");
                AddPlot(new Stroke(Brushes.DodgerBlue, DashStyleHelper.Solid, hisWid), PlotStyle.Bar, "SUP");
                AddPlot(new Stroke(Brushes.Blue, DashStyleHelper.Solid, 3), PlotStyle.Line, "RSIBUF");
                AddPlot(new Stroke(Brushes.BlueViolet, DashStyleHelper.Solid, 1), PlotStyle.Line, "MARSIOMA");
                AddLine(new Stroke(Brushes.DarkGray, DashStyleHelper.Dot, 1), 0, "ZERO AXIS");
            }
            else if (State == State.Configure)
            {
                _onBarClose = Calculate == Calculate.OnBarClose;
                _kOnBar = _onBarClose ? 1 : 0;
                dtInd = DateTime.MinValue;
                dtCur = DateTime.MinValue;
                _nMax = nMax;// MaximumBarsLookBack == MaximumBarsLookBack.Infinite ? nMax : 256;
                ParamIni();
            }
            else if (State == State.DataLoaded)
            {
                sTime = new Series<DateTime>(this);
                sClose = new Series<double>(this);
                sOpen = new Series<double>(this);
                sHigh = new Series<double>(this);
                sLow = new Series<double>(this);
                sVol = new Series<double>(this);
                /// 
                rsiSrc = new Series<double>(this);
                rsibuf = new Series<double>(this);
                bup = new Series<double>(this);
                bdn = new Series<double>(this);
                sdn = new Series<double>(this);
                sup = new Series<double>(this);
                posbuf = new Series<double>(this);
                negbuf = new Series<double>(this);
                marsioma = new Series<double>(this);
                ccma = new Series<double>(this);
            }
        }

        private void ParamIni()
        {
            //tableFont = new SimpleFont(lFont, fSzTable);
            dtAlert = DateTime.MinValue;
            dtAlertAux = DateTime.MinValue;
            _sFName = @"\sounds\" + soundFName;
            _minBars = 25;
            alertIni = false;
        }

        private int _kOnBar = 1, _minBars = 25, _kDrawMin = 5, _nMax;
        private string strEA = "RMARSI_";
        private DateTime dtInd, dtCur;
        private bool _onBarClose = true;
        private readonly object _obLock0 = new object();
        /// 
        private int cInd;
        bool alertIni = false;
        DateTime dtAlert, dtAlertAux;
        private string _sFName = string.Empty;
        //indicator
        int objLnCPrev = 0, objBoxCPrev = 0, objTxtCPrev = 0;
        /// 
        private Series<DateTime> sTime;
        private Series<double> sOpen, sClose, sHigh, sLow, sVol,
            rsiSrc, rsibuf, bup, bdn, sdn, sup, posbuf, negbuf, marsioma,
            ccma;
        private bool hlDrawOnce = false;
        int _atrSpPd = 20;
        double _arrMulti = 0.3;


        protected override void OnBarUpdate()
        {
            try
            {
                sOpen[0] = Open[0];
                sClose[0] = Close[0];
                sHigh[0] = High[0];
                sLow[0] = Low[0];
                sTime[0] = Time[0];
                sVol[0] = Volume[0];
                //
                int _index = CurrentBar, _gSz = Bars.Count;
                bool isFirst = _index == 0;
                bool isLast = CurrentBar == _gSz - _kOnBar - 1;
                //
                f_fetchSrc(_index, ref sClose, ref sOpen, ref sHigh, ref sLow, RSIOMA_PRICE, ref rsiSrc);
                f_ma_type(_index, ref rsiSrc, RSIOMA, RSIOMA_MODE, ref ccma);
                double rel = 0.0;
                if (!isFirst)
                {
                    rel = ccma[0] - ccma[1];
                }
                double sump = 0.0, sumn = 0;
                if (rel > 0)
                {
                    sump = rel;
                }
                else
                {
                    sumn = rel * -1.0;
                }
                posbuf[0] = 0;
                negbuf[0] = 0;
                if (!isFirst)
                {
                    posbuf[0] = (posbuf[1] * (double)(RSIOMA - 1) + sump) / (double)(RSIOMA);
                    negbuf[0] = (negbuf[1] * (double)(RSIOMA - 1) + sumn) / (double)(RSIOMA);
                }
                if (negbuf[0] == 0.0)
                {
                    rsibuf[0] = 0.0;
                }
                else
                {
                    rsibuf[0] = 100.0 - 100.0 / (1 + posbuf[0] / negbuf[0]);
                    if (rsibuf[0] > MainTrendLong)
                    {
                        bup[0] = -10.0;
                        bdn[0] = 0.0;
                        sdn[0] = 0.0;
                        sup[0] = 0.0;
                    }
                    if (rsibuf[0] < MainTrendShort)
                    {
                        bup[0] = 0.0;
                        bdn[0] = -10.0;
                        sdn[0] = 0.0;
                        sup[0] = 0.0;
                    }
                    if (!isFirst)
                    {
                        if (rsibuf[0] < BuyTrigger && rsibuf[0] > rsibuf[1])
                        {
                            bup[0] = 0.0;
                            bdn[0] = 0.0;
                            sdn[0] = 0.0;
                            sup[0] = -10.0;
                        }
                        if (rsibuf[0] > SellTrigger && rsibuf[0] < rsibuf[1])
                        {
                            bup[0] = 0.0;
                            bdn[0] = 0.0;
                            sdn[0] = -10.0;
                            sup[0] = 0.0;
                        }
                    }
                }
                f_ma_type(_index, ref rsibuf, Ma_RSIOMA, Ma_RSIOMA_MODE, ref marsioma);
                //
                MARSIOMA[0] = marsioma[0];
                RSIBUF[0] = rsibuf[0];
                BUP[0] = 0.0;
                BDN[0] = 0.0;
                SDN[0] = 0.0;
                SUP[0] = 0.0;
                BUP.Reset(0);
                BDN.Reset(0);
                SDN.Reset(0);
                BUP.Reset(0);
                if (bup[0] != 0)
                {
                    BUP[0] = bup[0];
                }
                if (bdn[0] != 0)
                {
                    BDN[0] = bdn[0];
                }
                if (sdn[0] != 0)
                {
                    SDN[0] = sdn[0];
                }
                if (sup[0] != 0)
                {
                    SUP[0] = sup[0];
                }
                //
                if (isLast && !hlDrawOnce)
                {
                    hlDrawOnce = true;
                    //
                    int hlnW = 1;
                    var hlnStyle = DashStyleHelper.Dot;
                    Draw.HorizontalLine(this, strEA + "NIVEL0", false,
                                                        BuyTrigger,
                                                        BuyTriggerColor, hlnStyle, 1);
                    Draw.HorizontalLine(this, strEA + "NIVEL1", false,
                                                        SellTrigger,
                                                        SellTriggerColor, hlnStyle, 1);
                    Draw.HorizontalLine(this, strEA + "NIVEL2", false,
                                                        MainTrendLong,
                                                        MainTrendLongColor, hlnStyle, 1);
                    Draw.HorizontalLine(this, strEA + "NIVEL3", false,
                                                        MainTrendShort,
                                                        MainTrendShortColor, hlnStyle, 1);
                }
                //
                if (isLast && _gSz >= _minBars && _gSz > alertBarIndex)
                {
                    if (Time[1].Subtract(dtInd).TotalSeconds > 0 || _gSz > cInd)
                    {
                        int _alertBarIndex = alertBarIndex;
                        if (_onBarClose) _alertBarIndex -= 1;
                        if (_alertBarIndex < 0) _alertBarIndex = 0;
                        ///alert
                        bool _alertUpMain = rsibuf[_alertBarIndex] > BuyTrigger && rsibuf[_alertBarIndex + 1] <= BuyTrigger;
                        bool _alertDnMain = rsibuf[_alertBarIndex] < SellTrigger && rsibuf[_alertBarIndex + 1] >= SellTrigger;
                        bool _alertUpAux = sup[_alertBarIndex] == -10 && sup[_alertBarIndex + 1] == 0;
                        bool _alertDnAux = sdn[_alertBarIndex] == -10 && sdn[_alertBarIndex + 1] == 0;
                        if (MainAlerts &&
                            Time[1].Subtract(dtAlert).TotalSeconds > 0 &&
                            alertIni &&
                            (_alertUpMain || _alertDnMain))
                        {
                            dtAlert = Time[1];
                            Alert(alertTitle, Priority.High,
                                        alertMessage ? (_alertUpMain ? "Up crossed " + BuyTrigger.ToString() : "Down crossed " + SellTrigger.ToString()) : string.Empty,
                                        alertSound ? NinjaTrader.Core.Globals.InstallDir + _sFName : String.Empty,
                                        15, Brushes.Transparent,
                                        _alertUpMain ?
                                        Brushes.Aqua :
                                        Brushes.Red);
                        }
                        if (AuxiliaryAlerts &&
                           Time[1].Subtract(dtAlertAux).TotalSeconds > 0 &&
                           alertIni &&
                           (_alertUpAux || _alertDnAux))
                        {
                            dtAlertAux = Time[1];
                            Alert(alertTitle, Priority.High,
                                        alertMessage ? (_alertUpAux ? "Bullish reversal imminent" : "Bearish reversal imminent") : string.Empty,
                                        alertSound ? NinjaTrader.Core.Globals.InstallDir + _sFName : String.Empty,
                                        15, Brushes.Transparent,
                                        _alertUpAux ?
                                        Brushes.Aqua :
                                        Brushes.Red);
                        }
                        alertIni = true;
                    }
                    cInd = _gSz;
                    dtInd = Time[1];
                }
            }
            //catch (Exception e) { Print("OnBarUpdate: " + e.ToString()); }
            catch { }
        }

        void f_fetchSrc(int _index,
            ref Series<double> _close,
            ref Series<double> _open,
            ref Series<double> _high,
            ref Series<double> _low,
            RENKOMARSI_PRICE_SRC _src,
            ref Series<double> _ret)
        {
            if (_src == RENKOMARSI_PRICE_SRC.OPEN)
                _ret[0] = _open[0];
            if (_src == RENKOMARSI_PRICE_SRC.HIGH)
                _ret[0] = _high[0];
            if (_src == RENKOMARSI_PRICE_SRC.LOW)
                _ret[0] = _low[0];
            if (_src == RENKOMARSI_PRICE_SRC.CLOSE)
                _ret[0] = _close[0];
            if (_src == RENKOMARSI_PRICE_SRC.HL2)
                _ret[0] = (_high[0] + _low[0]) * 0.5;
            if (_src == RENKOMARSI_PRICE_SRC.HLC3)
                _ret[0] = (_high[0] + _low[0] + _close[0]) / 3;
            if (_src == RENKOMARSI_PRICE_SRC.OHLC4)
                _ret[0] = (_high[0] + _low[0] + _close[0] + _open[0]) * 0.25;
            if (_src == RENKOMARSI_PRICE_SRC.HLCC4)
                _ret[0] = (_high[0] + _low[0] + _close[0] * 2) * 0.25;
        }

        private void f_ma_type(int _index,
            ref Series<double> _src, int _len,
            RENKOMARSI_MA_TYPE _type,
            ref Series<double> _ret)
        {
            if (_type == RENKOMARSI_MA_TYPE.SMA)
                f_sma(_index, ref _src, _len, ref _ret);
            if (_type == RENKOMARSI_MA_TYPE.EMA)
                f_ema(_index, ref _src, _len, ref _ret);
            if (_type == RENKOMARSI_MA_TYPE.SMMA)
                f_rma(_index, ref _src, _len, ref _ret);
            if (_type == RENKOMARSI_MA_TYPE.WMA)
                f_wma(_index, ref _src, _len, ref _ret);
        }

        private void f_ema(int _index, ref Series<double> _src, int _len, ref Series<double> _ret)
        {
            if (_len == 0) return;
            if (_index == 0)
                _ret[0] = _src[0];
            else
                _ret[0] = (2.0 * _src[0] + ((double)_len - 1.0) * _ret[1]) / ((double)_len + 1.0);
        }

        private void f_rma(int _index, ref Series<double> _src, int _len, ref Series<double> _ret)
        {
            if (_len == 0) return;
            if (_index == 0)
                _ret[0] = _src[0];
            else
                _ret[0] = (_ret[1] * (_len - 1) + _src[0]) / (double)_len;
        }

        private void f_sma(int _index, ref Series<double> _src, int _len, ref Series<double> _ret)
        {
            if (_len == 0) return;
            double _sum = 0.0;
            for (int ii = 0; ii < _len; ii++)
            {
                if (ii <= _index)
                    _sum += _src[ii];
            }
            _ret[0] = _sum / (double)(_len);
        }

        private void f_wma(int _index, ref Series<double> _src, int _len, ref Series<double> _ret)
        {
            if (_len == 0) return;
            if (_index < _len - 1) _ret[0] = _src[0];
            else
            {
                int ii = 0;
                double _sum = 0, weight = 0;
                for (ii = 1; ii <= _len; ii++)
                {
                    weight += (double)ii;
                }
                if (weight == 0)
                    return;
                for (ii = 0; ii < _len; ii++)
                {
                    _sum += _src[ii] * (double)(_len - ii);
                }
                _ret[0] = _sum / weight;
            }
        }

        const double chartMaxVal = 100, chartMinVal = -10;
        public override void OnCalculateMinMax()
        {
            try
            {
                MinValue = chartMinVal;
                MaxValue = chartMaxVal;
            }
            catch { }
        }

        #region Properties 
        [Browsable(false)]
        [XmlIgnore()]
        public Series<double> BDN
        {
            get { return Values[0]; }
        }
        [Browsable(false)]
        [XmlIgnore()]
        public Series<double> BUP
        {
            get { return Values[1]; }
        }
        [Browsable(false)]
        [XmlIgnore()]
        public Series<double> SDN
        {
            get { return Values[2]; }
        }
        [Browsable(false)]
        [XmlIgnore()]
        public Series<double> SUP
        {
            get { return Values[3]; }
        }
        [Browsable(false)]
        [XmlIgnore()]
        public Series<double> RSIBUF
        {
            get { return Values[4]; }
        }
        [Browsable(false)]
        [XmlIgnore()]
        public Series<double> MARSIOMA
        {
            get { return Values[5]; }
        }


        [Range(1, int.MaxValue), NinjaScriptProperty]
        [Display(ResourceType = typeof(Custom.Resource), Name = "RSIOMA Period", GroupName = "1. Indicator Setting", Order = 0)]
        public int RSIOMA
        { get; set; }

        [Range(0, int.MaxValue), NinjaScriptProperty]
        [Display(ResourceType = typeof(Custom.Resource), Name = "RSIOMA Mode", GroupName = "1. Indicator Setting", Order = 1)]
        public RENKOMARSI_MA_TYPE RSIOMA_MODE
        { get; set; }

        [Range(0, int.MaxValue), NinjaScriptProperty]
        [Display(ResourceType = typeof(Custom.Resource), Name = "RSIOMA Price", GroupName = "1. Indicator Setting", Order = 2)]
        public RENKOMARSI_PRICE_SRC RSIOMA_PRICE
        { get; set; }

        [Range(1, int.MaxValue), NinjaScriptProperty]
        [Display(ResourceType = typeof(Custom.Resource), Name = "MA of RSIOMA Period", GroupName = "1. Indicator Setting", Order = 3)]
        public int Ma_RSIOMA
        { get; set; }

        [Range(0, int.MaxValue), NinjaScriptProperty]
        [Display(ResourceType = typeof(Custom.Resource), Name = "MA of RSIOMA Mode", GroupName = "1. Indicator Setting", Order = 4)]
        public RENKOMARSI_MA_TYPE Ma_RSIOMA_MODE
        { get; set; }

        [Range(0, int.MaxValue), NinjaScriptProperty]
        [Display(ResourceType = typeof(Custom.Resource), Name = "Buy Trigger", GroupName = "1. Indicator Setting", Order = 10)]
        public int BuyTrigger
        { get; set; }

        [Range(0, int.MaxValue), NinjaScriptProperty]
        [Display(ResourceType = typeof(Custom.Resource), Name = "Sell Trigger", GroupName = "1. Indicator Setting", Order = 11)]
        public int SellTrigger
        { get; set; }

        [NinjaScriptProperty]
        [XmlIgnore]
        [Display(ResourceType = typeof(Custom.Resource), Name = "Buy Trigger Color", GroupName = "1. Indicator Setting", Order = 12)]
        public Brush BuyTriggerColor
        { get; set; }
        [Browsable(false)]
        public string BuyTriggerColorSerialize
        {
            get { return Serialize.BrushToString(BuyTriggerColor); }
            set { BuyTriggerColor = Serialize.StringToBrush(value); }
        }
        [NinjaScriptProperty]
        [XmlIgnore]
        [Display(ResourceType = typeof(Custom.Resource), Name = "Sell Trigger Color", GroupName = "1. Indicator Setting", Order = 13)]
        public Brush SellTriggerColor
        { get; set; }
        [Browsable(false)]
        public string SellTriggerColorSerialize
        {
            get { return Serialize.BrushToString(SellTriggerColor); }
            set { SellTriggerColor = Serialize.StringToBrush(value); }
        }

        [Range(0, int.MaxValue), NinjaScriptProperty]
        [Display(ResourceType = typeof(Custom.Resource), Name = "Main Trend Long", GroupName = "1. Indicator Setting", Order = 15)]
        public int MainTrendLong
        { get; set; }

        [Range(0, int.MaxValue), NinjaScriptProperty]
        [Display(ResourceType = typeof(Custom.Resource), Name = "Main Trend Short", GroupName = "1. Indicator Setting", Order = 16)]
        public int MainTrendShort
        { get; set; }

        [NinjaScriptProperty]
        [XmlIgnore]
        [Display(ResourceType = typeof(Custom.Resource), Name = "Main Trend Long Color", GroupName = "1. Indicator Setting", Order = 17)]
        public Brush MainTrendLongColor
        { get; set; }
        [Browsable(false)]
        public string MainTrendLongColorSerialize
        {
            get { return Serialize.BrushToString(MainTrendLongColor); }
            set { MainTrendLongColor = Serialize.StringToBrush(value); }
        }
        [NinjaScriptProperty]
        [XmlIgnore]
        [Display(ResourceType = typeof(Custom.Resource), Name = "Main Trend Short Color", GroupName = "1. Indicator Setting", Order = 18)]
        public Brush MainTrendShortColor
        { get; set; }
        [Browsable(false)]
        public string MainTrendShortColorSerialize
        {
            get { return Serialize.BrushToString(MainTrendShortColor); }
            set { MainTrendShortColor = Serialize.StringToBrush(value); }
        }


        //[Range(0, 1), NinjaScriptProperty]
        //[Display(ResourceType = typeof(Custom.Resource), Name = "Enable Alert?", GroupName = "2. Alert Setting", Order = 80)]
        //public bool alertOn
        //{ get; set; }

        [Range(0, 1), NinjaScriptProperty]
        [Display(ResourceType = typeof(Custom.Resource), Name = "Main Alerts?", GroupName = "2. Alert Setting", Order = 80)]
        public bool MainAlerts
        { get; set; }

        [Range(0, 1), NinjaScriptProperty]
        [Display(ResourceType = typeof(Custom.Resource), Name = "Auxiliary Alerts?", GroupName = "2. Alert Setting", Order = 81)]
        public bool AuxiliaryAlerts
        { get; set; }

        [Range(0, int.MaxValue), NinjaScriptProperty]
        [Display(ResourceType = typeof(Custom.Resource), Name = "Alert Bar Index", GroupName = "2. Alert Setting", Order = 91)]
        public int alertBarIndex
        { get; set; }

        [Range(0, 1), NinjaScriptProperty]
        [Display(ResourceType = typeof(Custom.Resource), Name = "Message", GroupName = "2. Alert Setting", Order = 92)]
        public bool alertMessage
        { get; set; }

        [NinjaScriptProperty]
        [Display(ResourceType = typeof(Custom.Resource), Name = "Message Title", GroupName = "2. Alert Setting", Order = 93)]
        public string alertTitle
        { get; set; }

        [Range(0, 1), NinjaScriptProperty]
        [Display(ResourceType = typeof(Custom.Resource), Name = "Sound", GroupName = "2. Alert Setting", Order = 94)]
        public bool alertSound
        { get; set; }

        [NinjaScriptProperty]
        [Display(ResourceType = typeof(Custom.Resource), Name = "Sound File Name", GroupName = "2. Alert Setting", Order = 95)]
        public string soundFName
        { get; set; }

        //[Range(20, int.MaxValue), NinjaScriptProperty]
        //[Display(ResourceType = typeof(Custom.Resource), Name = "Max Bars To Calculate", GroupName = "5. Misc Setting", Order = 100)]
        private int nMax;
        //{ get; set; }


        #endregion

    }
}

public enum RENKOMARSI_PRICE_SRC
{
    OPEN,
    HIGH,
    LOW,
    CLOSE,
    HL2,
    HLC3,
    OHLC4,
    HLCC4,
}


public enum RENKOMARSI_MA_TYPE
{
    SMA,
    EMA,
    SMMA,
    WMA,
}

#region NinjaScript generated code. Neither change nor remove.

namespace NinjaTrader.NinjaScript.Indicators
{
	public partial class Indicator : NinjaTrader.Gui.NinjaScript.IndicatorRenderBase
	{
		private RenkoMarsi[] cacheRenkoMarsi;
		public RenkoMarsi RenkoMarsi(int rSIOMA, RENKOMARSI_MA_TYPE rSIOMA_MODE, RENKOMARSI_PRICE_SRC rSIOMA_PRICE, int ma_RSIOMA, RENKOMARSI_MA_TYPE ma_RSIOMA_MODE, int buyTrigger, int sellTrigger, Brush buyTriggerColor, Brush sellTriggerColor, int mainTrendLong, int mainTrendShort, Brush mainTrendLongColor, Brush mainTrendShortColor, bool mainAlerts, bool auxiliaryAlerts, int alertBarIndex, bool alertMessage, string alertTitle, bool alertSound, string soundFName)
		{
			return RenkoMarsi(Input, rSIOMA, rSIOMA_MODE, rSIOMA_PRICE, ma_RSIOMA, ma_RSIOMA_MODE, buyTrigger, sellTrigger, buyTriggerColor, sellTriggerColor, mainTrendLong, mainTrendShort, mainTrendLongColor, mainTrendShortColor, mainAlerts, auxiliaryAlerts, alertBarIndex, alertMessage, alertTitle, alertSound, soundFName);
		}

		public RenkoMarsi RenkoMarsi(ISeries<double> input, int rSIOMA, RENKOMARSI_MA_TYPE rSIOMA_MODE, RENKOMARSI_PRICE_SRC rSIOMA_PRICE, int ma_RSIOMA, RENKOMARSI_MA_TYPE ma_RSIOMA_MODE, int buyTrigger, int sellTrigger, Brush buyTriggerColor, Brush sellTriggerColor, int mainTrendLong, int mainTrendShort, Brush mainTrendLongColor, Brush mainTrendShortColor, bool mainAlerts, bool auxiliaryAlerts, int alertBarIndex, bool alertMessage, string alertTitle, bool alertSound, string soundFName)
		{
			if (cacheRenkoMarsi != null)
				for (int idx = 0; idx < cacheRenkoMarsi.Length; idx++)
					if (cacheRenkoMarsi[idx] != null && cacheRenkoMarsi[idx].RSIOMA == rSIOMA && cacheRenkoMarsi[idx].RSIOMA_MODE == rSIOMA_MODE && cacheRenkoMarsi[idx].RSIOMA_PRICE == rSIOMA_PRICE && cacheRenkoMarsi[idx].Ma_RSIOMA == ma_RSIOMA && cacheRenkoMarsi[idx].Ma_RSIOMA_MODE == ma_RSIOMA_MODE && cacheRenkoMarsi[idx].BuyTrigger == buyTrigger && cacheRenkoMarsi[idx].SellTrigger == sellTrigger && cacheRenkoMarsi[idx].BuyTriggerColor == buyTriggerColor && cacheRenkoMarsi[idx].SellTriggerColor == sellTriggerColor && cacheRenkoMarsi[idx].MainTrendLong == mainTrendLong && cacheRenkoMarsi[idx].MainTrendShort == mainTrendShort && cacheRenkoMarsi[idx].MainTrendLongColor == mainTrendLongColor && cacheRenkoMarsi[idx].MainTrendShortColor == mainTrendShortColor && cacheRenkoMarsi[idx].MainAlerts == mainAlerts && cacheRenkoMarsi[idx].AuxiliaryAlerts == auxiliaryAlerts && cacheRenkoMarsi[idx].alertBarIndex == alertBarIndex && cacheRenkoMarsi[idx].alertMessage == alertMessage && cacheRenkoMarsi[idx].alertTitle == alertTitle && cacheRenkoMarsi[idx].alertSound == alertSound && cacheRenkoMarsi[idx].soundFName == soundFName && cacheRenkoMarsi[idx].EqualsInput(input))
						return cacheRenkoMarsi[idx];
			return CacheIndicator<RenkoMarsi>(new RenkoMarsi(){ RSIOMA = rSIOMA, RSIOMA_MODE = rSIOMA_MODE, RSIOMA_PRICE = rSIOMA_PRICE, Ma_RSIOMA = ma_RSIOMA, Ma_RSIOMA_MODE = ma_RSIOMA_MODE, BuyTrigger = buyTrigger, SellTrigger = sellTrigger, BuyTriggerColor = buyTriggerColor, SellTriggerColor = sellTriggerColor, MainTrendLong = mainTrendLong, MainTrendShort = mainTrendShort, MainTrendLongColor = mainTrendLongColor, MainTrendShortColor = mainTrendShortColor, MainAlerts = mainAlerts, AuxiliaryAlerts = auxiliaryAlerts, alertBarIndex = alertBarIndex, alertMessage = alertMessage, alertTitle = alertTitle, alertSound = alertSound, soundFName = soundFName }, input, ref cacheRenkoMarsi);
		}
	}
}

namespace NinjaTrader.NinjaScript.MarketAnalyzerColumns
{
	public partial class MarketAnalyzerColumn : MarketAnalyzerColumnBase
	{
		public Indicators.RenkoMarsi RenkoMarsi(int rSIOMA, RENKOMARSI_MA_TYPE rSIOMA_MODE, RENKOMARSI_PRICE_SRC rSIOMA_PRICE, int ma_RSIOMA, RENKOMARSI_MA_TYPE ma_RSIOMA_MODE, int buyTrigger, int sellTrigger, Brush buyTriggerColor, Brush sellTriggerColor, int mainTrendLong, int mainTrendShort, Brush mainTrendLongColor, Brush mainTrendShortColor, bool mainAlerts, bool auxiliaryAlerts, int alertBarIndex, bool alertMessage, string alertTitle, bool alertSound, string soundFName)
		{
			return indicator.RenkoMarsi(Input, rSIOMA, rSIOMA_MODE, rSIOMA_PRICE, ma_RSIOMA, ma_RSIOMA_MODE, buyTrigger, sellTrigger, buyTriggerColor, sellTriggerColor, mainTrendLong, mainTrendShort, mainTrendLongColor, mainTrendShortColor, mainAlerts, auxiliaryAlerts, alertBarIndex, alertMessage, alertTitle, alertSound, soundFName);
		}

		public Indicators.RenkoMarsi RenkoMarsi(ISeries<double> input , int rSIOMA, RENKOMARSI_MA_TYPE rSIOMA_MODE, RENKOMARSI_PRICE_SRC rSIOMA_PRICE, int ma_RSIOMA, RENKOMARSI_MA_TYPE ma_RSIOMA_MODE, int buyTrigger, int sellTrigger, Brush buyTriggerColor, Brush sellTriggerColor, int mainTrendLong, int mainTrendShort, Brush mainTrendLongColor, Brush mainTrendShortColor, bool mainAlerts, bool auxiliaryAlerts, int alertBarIndex, bool alertMessage, string alertTitle, bool alertSound, string soundFName)
		{
			return indicator.RenkoMarsi(input, rSIOMA, rSIOMA_MODE, rSIOMA_PRICE, ma_RSIOMA, ma_RSIOMA_MODE, buyTrigger, sellTrigger, buyTriggerColor, sellTriggerColor, mainTrendLong, mainTrendShort, mainTrendLongColor, mainTrendShortColor, mainAlerts, auxiliaryAlerts, alertBarIndex, alertMessage, alertTitle, alertSound, soundFName);
		}
	}
}

namespace NinjaTrader.NinjaScript.Strategies
{
	public partial class Strategy : NinjaTrader.Gui.NinjaScript.StrategyRenderBase
	{
		public Indicators.RenkoMarsi RenkoMarsi(int rSIOMA, RENKOMARSI_MA_TYPE rSIOMA_MODE, RENKOMARSI_PRICE_SRC rSIOMA_PRICE, int ma_RSIOMA, RENKOMARSI_MA_TYPE ma_RSIOMA_MODE, int buyTrigger, int sellTrigger, Brush buyTriggerColor, Brush sellTriggerColor, int mainTrendLong, int mainTrendShort, Brush mainTrendLongColor, Brush mainTrendShortColor, bool mainAlerts, bool auxiliaryAlerts, int alertBarIndex, bool alertMessage, string alertTitle, bool alertSound, string soundFName)
		{
			return indicator.RenkoMarsi(Input, rSIOMA, rSIOMA_MODE, rSIOMA_PRICE, ma_RSIOMA, ma_RSIOMA_MODE, buyTrigger, sellTrigger, buyTriggerColor, sellTriggerColor, mainTrendLong, mainTrendShort, mainTrendLongColor, mainTrendShortColor, mainAlerts, auxiliaryAlerts, alertBarIndex, alertMessage, alertTitle, alertSound, soundFName);
		}

		public Indicators.RenkoMarsi RenkoMarsi(ISeries<double> input , int rSIOMA, RENKOMARSI_MA_TYPE rSIOMA_MODE, RENKOMARSI_PRICE_SRC rSIOMA_PRICE, int ma_RSIOMA, RENKOMARSI_MA_TYPE ma_RSIOMA_MODE, int buyTrigger, int sellTrigger, Brush buyTriggerColor, Brush sellTriggerColor, int mainTrendLong, int mainTrendShort, Brush mainTrendLongColor, Brush mainTrendShortColor, bool mainAlerts, bool auxiliaryAlerts, int alertBarIndex, bool alertMessage, string alertTitle, bool alertSound, string soundFName)
		{
			return indicator.RenkoMarsi(input, rSIOMA, rSIOMA_MODE, rSIOMA_PRICE, ma_RSIOMA, ma_RSIOMA_MODE, buyTrigger, sellTrigger, buyTriggerColor, sellTriggerColor, mainTrendLong, mainTrendShort, mainTrendLongColor, mainTrendShortColor, mainAlerts, auxiliaryAlerts, alertBarIndex, alertMessage, alertTitle, alertSound, soundFName);
		}
	}
}

#endregion
